@@ -1,24 +1,6 @@
 # Version
 from bip_utils._version import __version__
-# Base58
-from bip_utils.base58 import (
-    Base58ChecksumError, Base58Alphabets,
-    Base58Decoder, Base58Encoder,
-    Base58XmrDecoder, Base58XmrEncoder
-)
-# SS58
-from bip_utils.ss58 import (
-    SS58ChecksumError, SS58Decoder, SS58Encoder
-)
-# Bech32
-from bip_utils.bech32 import (
-    Bech32ChecksumError,
-    Bech32Decoder, Bech32Encoder,
-    BchBech32Decoder, BchBech32Encoder,
-    SegwitBech32Decoder, SegwitBech32Encoder
-)
-# WIF
-from bip_utils.wif import WifPubKeyModes, WifDecoder, WifEncoder
+
 # Address computation
 from bip_utils.addr import (
     BchAddrConverter,
@@ -40,6 +22,7 @@ from bip_utils.addr import (
     BchP2SHAddrDecoder, BchP2SHAddrEncoder, BchP2SHAddr,
     P2SHAddrDecoder, P2SHAddrEncoder, P2SHAddr,
     P2WPKHAddrDecoder, P2WPKHAddrEncoder, P2WPKHAddr,
+    P2TRAddrDecoder, P2TRAddrEncoder, P2TRAddr,
     SolAddrDecoder, SolAddrEncoder, SolAddr,
     SubstrateEd25519AddrDecoder, SubstrateEd25519AddrEncoder, SubstrateEd25519Addr,
     SubstrateSr25519AddrDecoder, SubstrateSr25519AddrEncoder, SubstrateSr25519Addr,
@@ -51,13 +34,31 @@ from bip_utils.addr import (
     XtzAddrPrefixes, XtzAddrDecoder, XtzAddrEncoder, XtzAddr,
     ZilAddrDecoder, ZilAddrEncoder, ZilAddr
 )
-# Generic coins configuration
-from bip_utils.coin_conf import CoinsConf
+# Algorand mnemonic
+from bip_utils.algorand.mnemonic import (
+    AlgorandEntropyBitLen, AlgorandLanguages, AlgorandWordsNum,
+    AlgorandEntropyGenerator,
+    AlgorandMnemonic,
+    AlgorandMnemonicDecoder, AlgorandMnemonicEncoder,
+    AlgorandMnemonicGenerator, AlgorandMnemonicValidator, AlgorandSeedGenerator
+)
+# Base58
+from bip_utils.base58 import (
+    Base58ChecksumError, Base58Alphabets,
+    Base58Decoder, Base58Encoder,
+    Base58XmrDecoder, Base58XmrEncoder
+)
+# Bech32
+from bip_utils.bech32 import (
+    Bech32ChecksumError,
+    Bech32Decoder, Bech32Encoder,
+    BchBech32Decoder, BchBech32Encoder,
+    SegwitBech32Decoder, SegwitBech32Encoder
+)
 # BIP38
 from bip_utils.bip.bip38 import Bip38PubKeyModes, Bip38EcKeysGenerator, Bip38Decrypter, Bip38Encrypter
 # BIP39
 from bip_utils.bip.bip39 import (
-    Bip39ChecksumError,
     Bip39EntropyBitLen, Bip39Languages, Bip39WordsNum,
     Bip39Mnemonic, Bip39MnemonicDecoder, Bip39MnemonicEncoder,
     Bip39EntropyGenerator, Bip39MnemonicGenerator, Bip39MnemonicValidator, Bip39SeedGenerator
@@ -78,34 +79,14 @@ from bip_utils.bip.bip44_base import (
 from bip_utils.bip.bip44 import Bip44
 from bip_utils.bip.bip49 import Bip49
 from bip_utils.bip.bip84 import Bip84
+from bip_utils.bip.bip86 import Bip86
 # BIP coins configuration
 from bip_utils.bip.conf.bip44 import Bip44Coins, Bip44Conf, Bip44ConfGetter
 from bip_utils.bip.conf.bip49 import Bip49Coins, Bip49Conf, Bip49ConfGetter
 from bip_utils.bip.conf.bip84 import Bip84Coins, Bip84Conf, Bip84ConfGetter
-# Monero
-from bip_utils.monero import (
-    MoneroKeyError, MoneroPublicKey, MoneroPrivateKey, MoneroSubaddress, Monero
-)
-# Monero mnemonic
-from bip_utils.monero.mnemonic import (
-    MoneroChecksumError,
-    MoneroEntropyBitLen, MoneroLanguages, MoneroWordsNum,
-    MoneroMnemonic, MoneroMnemonicDecoder, MoneroMnemonicEncoder,
-    MoneroEntropyGenerator, MoneroMnemonicGenerator, MoneroMnemonicValidator, MoneroSeedGenerator
-)
-# Monero configuration
-from bip_utils.monero.conf import MoneroCoins, MoneroConf
-# Substrate
-from bip_utils.substrate import (
-    SubstrateKeyError, SubstratePathError,
-    SubstratePublicKey, SubstratePrivateKey,
-    SubstratePathElem, SubstratePath, SubstratePathParser,
-    Substrate
-)
-# Substrate mnemonic
-from bip_utils.substrate.mnemonic import SubstrateBip39SeedGenerator
-# Substrate configuration
-from bip_utils.substrate.conf import SubstrateCoins, SubstrateConf
+from bip_utils.bip.conf.bip86 import Bip86Coins, Bip86Conf, Bip86ConfGetter
+# Generic coins configuration
+from bip_utils.coin_conf import CoinsConf
 # ECC
 from bip_utils.ecc import (
     EllipticCurveGetter, EllipticCurveTypes,
@@ -116,7 +97,42 @@ from bip_utils.ecc import (
     Secp256k1, Secp256k1Point, Secp256k1PublicKey, Secp256k1PrivateKey,
     Sr25519, Sr25519Point, Sr25519PublicKey, Sr25519PrivateKey
 )
+# Monero
+from bip_utils.monero import (
+    MoneroKeyError, MoneroPublicKey, MoneroPrivateKey, MoneroSubaddress, Monero
+)
+# Monero mnemonic
+from bip_utils.monero.mnemonic import (
+    MoneroEntropyBitLen, MoneroLanguages, MoneroWordsNum,
+    MoneroEntropyGenerator,
+    MoneroMnemonic,
+    MoneroMnemonicNoChecksumEncoder, MoneroMnemonicWithChecksumEncoder, MoneroMnemonicDecoder,
+    MoneroMnemonicEncoder,
+    MoneroMnemonicGenerator, MoneroMnemonicValidator, MoneroSeedGenerator
+)
+# Monero configuration
+from bip_utils.monero.conf import MoneroCoins, MoneroConf
+# Substrate
+from bip_utils.substrate import (
+    SubstrateKeyError, SubstratePathError,
+    SubstratePublicKey, SubstratePrivateKey,
+    SubstratePathElem, SubstratePath, SubstratePathParser,
+    Substrate
+)
+# Solana
+from bip_utils.solana import SplToken
+# SS58
+from bip_utils.ss58 import (
+    SS58ChecksumError, SS58Decoder, SS58Encoder
+)
+# Substrate mnemonic
+from bip_utils.substrate.mnemonic import SubstrateBip39SeedGenerator
+# Substrate configuration
+from bip_utils.substrate.conf import SubstrateCoins, SubstrateConf
 # Utils
 from bip_utils.utils.misc import (
     AlgoUtils, BitUtils, BytesUtils, CryptoUtils, DataBytes, IntegerUtils, StringUtils
 )
+from bip_utils.utils.mnemonic import MnemonicChecksumError
+# WIF
+from bip_utils.wif import WifPubKeyModes, WifDecoder, WifEncoder
