@@ -18,15 +18,17 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""Module for Ethereum address computation."""
+"""Module for Ethereum address encoding/decoding."""
 
 # Imports
 from typing import Any, Union
+from bip_utils.addr.addr_dec_utils import AddrDecUtils
+from bip_utils.addr.addr_key_validator import AddrKeyValidator
+from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
-from bip_utils.addr.utils import AddrUtils
 from bip_utils.coin_conf import CoinsConf
 from bip_utils.ecc import IPublicKey
-from bip_utils.utils.misc import ConvUtils, CryptoUtils
+from bip_utils.utils.misc import BytesUtils, CryptoUtils
 
 
 class EthAddrConst:
@@ -34,9 +36,11 @@ class EthAddrConst:
 
     # Start byte
     START_BYTE: int = 24
+    # Address length
+    ADDR_LEN: int = 40
 
 
-class EthAddrUtils:
+class _EthAddrUtils:
     """Class container for Ethereum address utility functions."""
 
     @staticmethod
@@ -52,28 +56,68 @@ class EthAddrUtils:
         """
 
         # Compute address digest
-        addr_hex_digest = ConvUtils.BytesToHexString(CryptoUtils.Kekkak256(addr))
+        addr_hex_digest = BytesUtils.ToHexString(CryptoUtils.Kekkak256(addr.lower()))
         # Encode it
         enc_addr = [c.upper() if (int(addr_hex_digest[i], 16) >= 8) else c.lower() for i, c in enumerate(addr)]
 
         return "".join(enc_addr)
 
 
-class EthAddr(IAddrEncoder):
+class EthAddrDecoder(IAddrDecoder):
     """
-    Ethereum address class.
-    It allows the Ethereum address generation.
+    Ethereum address decoder class.
+    It allows the Ethereum address decoding.
+    """
+
+    @staticmethod
+    def DecodeAddr(addr: str,
+                   **kwargs: Any) -> bytes:
+        """
+        Decode an Ethereum address to bytes.
+
+        Args:
+            addr (str): Address string
+
+        Other Parameters:
+            skip_chksum_enc (bool, optional): True to skip checksum encoding verification, false otherwise (default)
+
+        Returns:
+            bytes: Public key hash bytes
+
+        Raises:
+            ValueError: If the address encoding is not valid
+        """
+        skip_chksum_enc = kwargs.get("skip_chksum_enc", False)
+
+        # Validate and remove prefix
+        addr_no_prefix = AddrDecUtils.ValidateAndRemovePrefix(addr,
+                                                              CoinsConf.Ethereum.Params("addr_prefix"))
+        # Validate length
+        AddrDecUtils.ValidateLength(addr_no_prefix, EthAddrConst.ADDR_LEN)
+        # Check checksum encoding
+        if not skip_chksum_enc and addr_no_prefix != _EthAddrUtils.ChecksumEncode(addr_no_prefix):
+            raise ValueError("Invalid checksum encode")
+
+        return BytesUtils.FromHexString(addr_no_prefix)
+
+
+class EthAddrEncoder(IAddrEncoder):
+    """
+    Ethereum address encoder class.
+    It allows the Ethereum address encoding.
     """
 
     @staticmethod
     def EncodeKey(pub_key: Union[bytes, IPublicKey],
                   **kwargs: Any) -> str:
         """
-        Get address in Ethereum format.
+        Encode a public key to Ethereum address.
 
         Args:
             pub_key (bytes or IPublicKey): Public key bytes or object
-            **kwargs: Not used
+
+        Other Parameters:
+            skip_chksum_enc (bool, optional): True to skip checksum encoding, false otherwise (default)
 
         Returns:
             str: Address string
@@ -82,9 +126,20 @@ class EthAddr(IAddrEncoder):
             ValueError: If the public key is not valid
             TypeError: If the public key is not secp256k1
         """
-        pub_key_obj = AddrUtils.ValidateAndGetSecp256k1Key(pub_key)
+        skip_chksum_enc = kwargs.get("skip_chksum_enc", False)
+
+        pub_key_obj = AddrKeyValidator.ValidateAndGetSecp256k1Key(pub_key)
 
         # First byte of the uncompressed key (i.e. 0x04) is not needed
-        kekkak_hex = ConvUtils.BytesToHexString(CryptoUtils.Kekkak256(pub_key_obj.RawUncompressed().ToBytes()[1:]))
+        kekkak_hex = BytesUtils.ToHexString(CryptoUtils.Kekkak256(pub_key_obj.RawUncompressed().ToBytes()[1:]))
         addr = kekkak_hex[EthAddrConst.START_BYTE:]
-        return CoinsConf.Ethereum.Params("addr_prefix") + EthAddrUtils.ChecksumEncode(addr)
+        return CoinsConf.Ethereum.Params("addr_prefix") + (_EthAddrUtils.ChecksumEncode(addr)
+                                                           if not skip_chksum_enc
+                                                           else addr)
+
+
+class EthAddr(EthAddrEncoder):
+    """
+    Ethereum address class.
+    Only kept for compatibility, EthAddrEncoder shall be used instead.
+    """
