@@ -18,14 +18,16 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""Module for Tezos address computation."""
+"""Module for Tezos address encoding/decoding."""
 
 # Imports
 from enum import Enum, unique
 from typing import Any, Union
+from bip_utils.addr.addr_dec_utils import AddrDecUtils
+from bip_utils.addr.addr_key_validator import AddrKeyValidator
+from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
-from bip_utils.addr.utils import AddrUtils
-from bip_utils.base58 import Base58Encoder
+from bip_utils.base58 import Base58ChecksumError, Base58Decoder, Base58Encoder
 from bip_utils.ecc import IPublicKey
 from bip_utils.utils.misc import CryptoUtils
 
@@ -42,25 +44,70 @@ class XtzAddrPrefixes(Enum):
 class XtzAddrConst:
     """Class container for Tezos address constants."""
 
-    # Digest length in bytes
-    DIGEST_BYTE_LEN: int = 20
+    # Blake2b length in bytes
+    BLAKE2B_BYTE_LEN: int = 20
 
 
-class XtzAddr(IAddrEncoder):
+class XtzAddrDecoder(IAddrDecoder):
     """
-    Tezos address class.
-    It allows the Tezos address generation.
+    Tezos address decoder class.
+    It allows the Tezos address decoding.
+    """
+
+    @staticmethod
+    def DecodeAddr(addr: str,
+                   **kwargs: Any) -> bytes:
+        """
+        Decode a Tezos address to bytes.
+
+        Args:
+            addr (str): Address string
+
+        Other Parameters:
+            prefix (XtzAddrPrefixes): Address prefix
+
+        Returns:
+            bytes: Public key hash bytes
+
+        Raises:
+            ValueError: If the address encoding is not valid
+            TypeError: If the prefix is not a XtzAddrPrefixes enum
+        """
+
+        # Get and check prefix
+        prefix = kwargs["prefix"]
+        if not isinstance(prefix, XtzAddrPrefixes):
+            raise TypeError("Address type is not an enumerative of XtzAddrPrefixes")
+
+        # Decode from base58
+        try:
+            addr_dec_bytes = Base58Decoder.CheckDecode(addr)
+        except Base58ChecksumError as ex:
+            raise ValueError("Invalid base58 checksum") from ex
+        else:
+            # Validate length
+            AddrDecUtils.ValidateLength(addr_dec_bytes,
+                                        len(prefix.value) + XtzAddrConst.BLAKE2B_BYTE_LEN)
+            # Validate and remove prefix
+            blake_bytes = AddrDecUtils.ValidateAndRemovePrefix(addr_dec_bytes, prefix.value)
+
+            return blake_bytes
+
+
+class XtzAddrEncoder(IAddrEncoder):
+    """
+    Tezos address encoder class.
+    It allows the Tezos address encoding.
     """
 
     @staticmethod
     def EncodeKey(pub_key: Union[bytes, IPublicKey],
                   **kwargs: Any) -> str:
         """
-        Get address in Tezos format.
+        Encode a public key to Tezos address.
 
         Args:
             pub_key (bytes or IPublicKey): Public key bytes or object
-            **kwargs: Not used
 
         Other Parameters:
             prefix (XtzAddrPrefixes): Address prefix
@@ -70,18 +117,26 @@ class XtzAddr(IAddrEncoder):
 
         Raises:
             ValueError: If the public key is not valid
-            TypeError: If the public key is not ed25519
+            TypeError: If the public key is not ed25519 or the prefix is not a XtzAddrPrefixes enum
         """
 
-        # Get and check address type
+        # Get and check prefix
         prefix = kwargs["prefix"]
         if not isinstance(prefix, XtzAddrPrefixes):
             raise TypeError("Address type is not an enumerative of XtzAddrPrefixes")
 
         # Get public key
-        pub_key_obj = AddrUtils.ValidateAndGetEd25519Key(pub_key)
+        pub_key_obj = AddrKeyValidator.ValidateAndGetEd25519Key(pub_key)
 
-        # Compute Blake2b and encode in Base58 with checksum
-        blake = CryptoUtils.Blake2b(pub_key_obj.RawCompressed().ToBytes()[1:],
-                                    digest_size=XtzAddrConst.DIGEST_BYTE_LEN)
-        return Base58Encoder.CheckEncode(prefix.value + blake)
+        # Compute Blake2b and encode in base58 with checksum
+        blake_bytes = CryptoUtils.Blake2b(pub_key_obj.RawCompressed().ToBytes()[1:],
+                                          digest_size=XtzAddrConst.BLAKE2B_BYTE_LEN)
+
+        return Base58Encoder.CheckEncode(prefix.value + blake_bytes)
+
+
+class XtzAddr(XtzAddrEncoder):
+    """
+    Tezos address class.
+    Only kept for compatibility, XtzAddrEncoder shall be used instead.
+    """
