@@ -18,13 +18,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""Module for Zilliqa address computation."""
+"""Module for Zilliqa address encoding/decoding."""
 
 # Imports
 from typing import Any, Union
+from bip_utils.addr.addr_dec_utils import AddrDecUtils
+from bip_utils.addr.addr_key_validator import AddrKeyValidator
+from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
-from bip_utils.addr.utils import AddrUtils
-from bip_utils.bech32 import Bech32Encoder
+from bip_utils.bech32 import Bech32ChecksumError, Bech32Decoder, Bech32Encoder
 from bip_utils.coin_conf import CoinsConf
 from bip_utils.ecc import IPublicKey
 from bip_utils.utils.misc import CryptoUtils
@@ -33,25 +35,57 @@ from bip_utils.utils.misc import CryptoUtils
 class ZilAddrConst:
     """Class container for Zilliqa address constants."""
 
-    # Digest length in bytes
-    DIGEST_BYTE_LEN: int = 20
+    # SHA-256 length in bytes
+    SHA256_BYTE_LEN: int = 20
 
 
-class ZilAddr(IAddrEncoder):
+class ZilAddrDecoder(IAddrDecoder):
     """
-    Zilliqa address class.
-    It allows the Zilliqa address generation.
+    Zilliqa address decoder class.
+    It allows the Zilliqa address decoding.
+    """
+
+    @staticmethod
+    def DecodeAddr(addr: str,
+                   **kwargs: Any) -> bytes:
+        """
+        Decode a Zilliqa address to bytes.
+
+        Args:
+            addr (str): Address string
+            **kwargs  : Not used
+
+        Returns:
+            bytes: Public key hash bytes
+
+        Raises:
+            ValueError: If the address encoding is not valid
+        """
+        try:
+            addr_dec_bytes = Bech32Decoder.Decode(CoinsConf.Zilliqa.Params("addr_hrp"),
+                                                  addr)
+        except Bech32ChecksumError as ex:
+            raise ValueError("Invalid bech32 checksum") from ex
+        else:
+            AddrDecUtils.ValidateLength(addr_dec_bytes, ZilAddrConst.SHA256_BYTE_LEN)
+            return addr_dec_bytes
+
+
+class ZilAddrEncoder(IAddrEncoder):
+    """
+    Zilliqa address encoder class.
+    It allows the Zilliqa address encoding.
     """
 
     @staticmethod
     def EncodeKey(pub_key: Union[bytes, IPublicKey],
                   **kwargs: Any) -> str:
         """
-        Get address in Zilliqa format.
+        Encode a public key to Zilliqa address.
 
         Args:
             pub_key (bytes or IPublicKey): Public key bytes or object
-            **kwargs: Not used
+            **kwargs                     : Not used
 
         Returns:
             str: Address string
@@ -60,8 +94,15 @@ class ZilAddr(IAddrEncoder):
             ValueError: If the public key is not valid
             TypeError: If the public key is not secp256k1
         """
-        pub_key_obj = AddrUtils.ValidateAndGetSecp256k1Key(pub_key)
+        pub_key_obj = AddrKeyValidator.ValidateAndGetSecp256k1Key(pub_key)
 
         key_hash = CryptoUtils.Sha256(pub_key_obj.RawCompressed().ToBytes())
         return Bech32Encoder.Encode(CoinsConf.Zilliqa.Params("addr_hrp"),
-                                    key_hash[-ZilAddrConst.DIGEST_BYTE_LEN:])
+                                    key_hash[-ZilAddrConst.SHA256_BYTE_LEN:])
+
+
+class ZilAddr(ZilAddrEncoder):
+    """
+    Zilliqa address class.
+    Only kept for compatibility, ZilAddrEncoder shall be used instead.
+    """
