@@ -20,26 +20,43 @@
 
 """
 Module for bech32 decoding/encoding.
-Reference: https://github.com/bitcoin/bips/blob/master/bip-0173.mediawiki.
+
+References:
+    https://github.com/bitcoin/bips/blob/master/bip-0173.mediawiki
+    https://github.com/bitcoin/bips/blob/master/bip-0350.mediawiki
 """
 
 # Imports
-from typing import List
+from enum import auto, Enum, unique
+from typing import Dict, List
 from bip_utils.bech32.bech32_base import Bech32DecoderBase, Bech32EncoderBase, Bech32BaseUtils
 from bip_utils.utils.misc import BytesUtils
 
 
+@unique
+class Bech32Encodings(Enum):
+    """Enumerative for Bech32 encoding types."""
+
+    BECH32 = auto()
+    BECH32M = auto()
+
+
 class Bech32Const:
     """Class container for Bech32 constants."""
 
     # Separator
     SEPARATOR: str = "1"
-    # Checkum length in bytes
+    # Checksum length in bytes
     CHECKSUM_BYTE_LEN: int = 6
     # Minimum data length in bytes
     DATA_MIN_BYTE_LEN: int = 2
     # Maximum data length in bytes
     DATA_MAX_BYTE_LEN: int = 40
+    # Encoding checksum constants
+    ENCODING_CHECKSUM_CONST: Dict[Bech32Encodings, int] = {
+        Bech32Encodings.BECH32: 1,
+        Bech32Encodings.BECH32M: 0x2bc830a3,
+    }
 
 
 class Bech32Utils:
@@ -51,7 +68,7 @@ class Bech32Utils:
         Computes the polynomial modulus.
 
         Args:
-            values (list): List of polynomial coefficients
+            values (list[int]): List of polynomial coefficients
 
         Returns:
             int: Computed modulus
@@ -78,56 +95,62 @@ class Bech32Utils:
             hrp (str): HRP
 
         Returns:
-            list: Expanded HRP values
+            list[int]: Expanded HRP values
         """
         # [upper 3 bits of each character] + [0] + [lower 5 bits of each character]
         return [ord(x) >> 5 for x in hrp] + [0] + [ord(x) & 0x1f for x in hrp]
 
     @staticmethod
     def ComputeChecksum(hrp: str,
-                        data: List[int]) -> List[int]:
+                        data: List[int],
+                        encoding: Bech32Encodings = Bech32Encodings.BECH32) -> List[int]:
         """
         Compute the checksum from the specified HRP and data.
 
         Args:
-            hrp (str)  : HRP
-            data (list): Data part
+            hrp (str)                           : HRP
+            data (list[int])                    : Data part
+            encoding (Bech32Encodings, optional): Encoding type (BECH32 by default)
 
         Returns:
-            list: Computed checksum
+            list[int]: Computed checksum
         """
 
         values = Bech32Utils.HrpExpand(hrp) + data
-        polymod = Bech32Utils.PolyMod(values + [0, 0, 0, 0, 0, 0]) ^ 1
+        polymod = Bech32Utils.PolyMod(values + [0, 0, 0, 0, 0, 0]) ^ Bech32Const.ENCODING_CHECKSUM_CONST[encoding]
         return [(polymod >> 5 * (5 - i)) & 0x1f for i in range(Bech32Const.CHECKSUM_BYTE_LEN)]
 
     @staticmethod
     def VerifyChecksum(hrp: str,
-                       data: List[int]) -> bool:
+                       data: List[int],
+                       encoding: Bech32Encodings = Bech32Encodings.BECH32) -> bool:
         """
         Verify the checksum from the specified HRP and converted data characters.
 
         Args:
-            hrp  (str) : HRP
-            data (list): Data part
+            hrp  (str)                          : HRP
+            data (list[int])                    : Data part
+            encoding (Bech32Encodings, optional): Encoding type (BECH32 by default)
 
         Returns:
             bool: True if valid, false otherwise
         """
-        return Bech32Utils.PolyMod(Bech32Utils.HrpExpand(hrp) + data) == 1
+        polymod = Bech32Utils.PolyMod(Bech32Utils.HrpExpand(hrp) + data)
+        return polymod == Bech32Const.ENCODING_CHECKSUM_CONST[encoding]
 
 
 class Bech32Encoder(Bech32EncoderBase):
     """
     Bech32 encoder class.
-    It provides methods for encoding to  Bech32 format.
+    It provides methods for encoding to Bech32 format.
     """
 
-    @staticmethod
-    def Encode(hrp: str,
+    @classmethod
+    def Encode(cls,
+               hrp: str,
                data: bytes) -> str:
         """
-        Encode to  Bech32.
+        Encode to Bech32.
 
         Args:
             hrp (str)   : HRP
@@ -140,7 +163,9 @@ class Bech32Encoder(Bech32EncoderBase):
             ValueError: If the data is not valid
         """
 
-        return Bech32Encoder._EncodeBech32(hrp, Bech32BaseUtils.ConvertToBase32(data), Bech32Const.SEPARATOR)
+        return cls._EncodeBech32(hrp,
+                                 Bech32BaseUtils.ConvertToBase32(data),
+                                 Bech32Const.SEPARATOR)
 
     @staticmethod
     def _ComputeChecksum(hrp: str,
@@ -149,11 +174,11 @@ class Bech32Encoder(Bech32EncoderBase):
         Compute the checksum from the specified HRP and data.
 
         Args:
-            hrp (str)  : HRP
-            data (list): Data part
+            hrp (str)       : HRP
+            data (list[int]): Data part
 
         Returns:
-            list: Computed checksum
+            list[int]: Computed checksum
         """
 
         # Same as Segwit
@@ -166,11 +191,12 @@ class Bech32Decoder(Bech32DecoderBase):
     It provides methods for decoding  Bech32 format.
     """
 
-    @staticmethod
-    def Decode(hrp: str,
+    @classmethod
+    def Decode(cls,
+               hrp: str,
                addr: str) -> bytes:
         """
-        Decode from  Bech32.
+        Decode from Bech32.
 
         Args:
             hrp (str) : Human readable part
@@ -185,7 +211,9 @@ class Bech32Decoder(Bech32DecoderBase):
         """
 
         # Decode string
-        hrp_got, data = Bech32Decoder._DecodeBech32(addr, Bech32Const.SEPARATOR, Bech32Const.CHECKSUM_BYTE_LEN)
+        hrp_got, data = cls._DecodeBech32(addr,
+                                          Bech32Const.SEPARATOR,
+                                          Bech32Const.CHECKSUM_BYTE_LEN)
 
         # Check HRP
         if hrp != hrp_got:
@@ -208,12 +236,10 @@ class Bech32Decoder(Bech32DecoderBase):
         Verify the checksum from the specified HRP and converted data characters.
 
         Args:
-            hrp  (str) : HRP
-            data (list): Data part
+            hrp  (str)      : HRP
+            data (list[int]): Data part
 
         Returns:
             bool: True if valid, false otherwise
         """
-
-        # Same as Segwit
         return Bech32Utils.VerifyChecksum(hrp, data)
