@@ -52,14 +52,14 @@ class Bip39EntropyGeneratorConst:
 
 class Bip39EntropyGenerator(EntropyGenerator):
     """
-    Entropy generator class.
+    BIP39 entropy generator class.
     It generates random entropy bytes with the specified length.
     """
 
     def __init__(self,
                  bits_len: Union[int, Bip39EntropyBitLen]) -> None:
         """
-        Construct class by specifying the bits length.
+        Construct class.
 
         Args:
             bits_len (int or Bip39EntropyBitLen): Entropy length in bits
