@@ -20,7 +20,7 @@
 
 """
 Module for BIP49 keys derivation.
-Reference: https://github.com/bitcoin/bips/blob/master/bip-0049.mediawiki.
+Reference: https://github.com/bitcoin/bips/blob/master/bip-0049.mediawiki
 """
 
 # Imports
@@ -33,7 +33,7 @@ from bip_utils.ecc import IPrivateKey
 
 
 class Bip49Const:
-    """Class container for BIP44 constants."""
+    """Class container for BIP49 constants."""
 
     # Specification name
     SPEC_NAME: str = "BIP-0049"
