@@ -20,7 +20,7 @@
 
 """
 Module for BIP84 keys derivation.
-Reference: https://github.com/bitcoin/bips/blob/master/bip-0084.mediawiki.
+Reference: https://github.com/bitcoin/bips/blob/master/bip-0084.mediawiki
 """
 
 # Imports
@@ -33,7 +33,7 @@ from bip_utils.ecc import IPrivateKey
 
 
 class Bip84Const:
-    """Class container for BIP44 constants."""
+    """Class container for BIP84 constants."""
 
     # Specification name
     SPEC_NAME: str = "BIP-0084"
