@@ -1,4 +1,4 @@
 from bip_utils.substrate.conf.substrate_coins import SubstrateCoins
 from bip_utils.substrate.conf.substrate_coin_conf import SubstrateCoinConf
-from bip_utils.substrate.conf.substrate_conf import *
+from bip_utils.substrate.conf.substrate_conf import SubstrateConf
 from bip_utils.substrate.conf.substrate_conf_getter import SubstrateConfGetter
