@@ -196,7 +196,7 @@ class SubstratePath:
     def __init__(self,
                  elems: Optional[Sequence[Union[str, SubstratePathElem]]] = None) -> None:
         """
-        Construct class by specifying the path elements.
+        Construct class.
 
         Args:
             elems (list, optional): Path elements
@@ -240,7 +240,7 @@ class SubstratePath:
         Get the path as a list of strings.
 
         Returns:
-            list: Path as a list of strings
+            list[str]: Path as a list of strings
         """
         return [str(elem) for elem in self.m_elems]
 
